"""
    WhyLabs API client

    WhyLabs API that enables end-to-end AI observability  # noqa: E501

    The version of the OpenAPI document: 0.1
    Contact: support@whylabs.ai
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "whylabs-client"
VERSION = "0.4.5"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
  "urllib3 >= 1.25.3",
  "python-dateutil",
]

setup(
    name=NAME,
    version=VERSION,
    description="WhyLabs API client",
    author="WhyLabs",
    author_email="support@whylabs.ai",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "WhyLabs API client"],
    python_requires=">=3.6",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache License 2.0",
    long_description_content_type="text/markdown",
    long_description="""\
    WhyLabs API that enables end-to-end AI observability  # noqa: E501
    """
)
